
# Type: prevents


holds between an entity whose application or use reduces the likelihood of a potential outcome. Typically used to associate a chemical substance, exposure, activity, or medical intervention that can prevent the onset a disease or phenotypic feature.

URI: [biolink:prevents](https://w3id.org/biolink/vocab/prevents)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects risk for](affects_risk_for.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002599 |
|  | | SEMMEDDB:PREVENTS |
| **In Subsets:** | | translator_minimal |

